@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Command line actions
+Command line action to start a new project
 """
 import datetime, logging, os, time
 
@@ -18,7 +18,7 @@ from optimus.start_project import ProjectStarter
 @arg('--dry-run', default=False, help="Dry run mode will perform all processus but will not create or modify anything")
 def init(args):
     """
-    The init action for the commandline
+    Create a new project from a project template
     """
     starttime = datetime.datetime.now()
     # Init, load and builds
@@ -30,11 +30,12 @@ def init(args):
     if args.dry_run:
         root_logger.warning("'Dry run' mode enabled")
     
-    # TODO: optionnal command option
+    # TODO: optionnal command option to specify another path where the project will 
+    #       be created
     project_directory = os.path.abspath(os.getcwd())
 
     loader = ProjectStarter(project_directory, args.name, dry_run=args.dry_run)
-    loader.install("optimus.defaults")
+    loader.install(args.template)
     
     endtime = datetime.datetime.now()
     root_logger.info('Done in %s', str(endtime-starttime))
